@@ -36,28 +36,29 @@
 
 from lazy_object_proxy import Proxy
 
-from univention.config_registry.backend import StrictModeException, SCOPE, ConfigRegistry, Load, ReadOnlyConfigRegistry as _RCR  # noqa: F401
-from univention.config_registry.handler import run_filter as filter, ConfigHandlers as configHandlers  # noqa: F401
-from univention.config_registry.misc import key_shell_escape, validate_key, INVALID_KEY_CHARS as invalid_key_chars  # noqa: F401
-from univention.config_registry.filters import filter_shell, filter_keys_only, filter_sort  # noqa: F401
+from univention.config_registry.backend import (  # noqa: F401
+    SCOPE, ConfigRegistry, Load, ReadOnlyConfigRegistry as _RCR, StrictModeException,
+)
+from univention.config_registry.filters import filter_keys_only, filter_shell, filter_sort  # noqa: F401
 from univention.config_registry.frontend import (  # noqa: F401
-	REPLOG_FILE, UnknownKeyException, main,
-	handler_set, handler_unset, handler_commit, handler_filter,
-	handler_get, handler_dump, handler_search,
-	handler_register, handler_unregister, handler_update,
+    REPLOG_FILE, UnknownKeyException, handler_commit, handler_dump, handler_filter, handler_get, handler_register,
+    handler_search, handler_set, handler_unregister, handler_unset, handler_update, main,
+)
+from univention.config_registry.handler import ConfigHandlers as configHandlers, run_filter as filter  # noqa: F401
+from univention.config_registry.misc import (  # noqa: F401
+    INVALID_KEY_CHARS as invalid_key_chars, key_shell_escape, validate_key,
 )
 from univention.debhelper import parseRfc822  # noqa: F401
 
+
 ucr = Proxy(lambda: _RCR().load(autoload=Load.ONCE))  # type: _RCR
 ucr_live = Proxy(lambda: _RCR().load(autoload=Load.ALWAYS))  # type: _RCR
 
 
 def ucr_factory():  # type: () -> ConfigRegistry
-	"""
-	Factory method to return private loaded UCR instance.
+    """
+    Factory method to return private loaded UCR instance.
 
-	:returns: A private UCR instance.
-	"""
-	return ConfigRegistry().load()
-
-# vim:set sw=4 ts=4 noet:
+    :returns: A private UCR instance.
+    """
+    return ConfigRegistry().load()
