@@ -1,13 +1,11 @@
 #!/usr/bin/python3
-"""
-Run (uninstalled) univention.config_registry to make sure all commands work
-"""
+"""Run (uninstalled) univention.config_registry to make sure all commands work"""
 from copy import deepcopy
 
 import pytest
 
-from univention.config_registry import main  # noqa: E402
 import univention.config_registry.frontend as ucrfe
+from univention.config_registry import main  # noqa: E402
 
 
 @pytest.fixture(autouse=True)
